clc; clear all; close all;


fprintf('\n Figure 1b: Multiplier in the stochastic vs deterministic exit model \n');
fprintf('\n Non-separable preferences \n');

% interest rate fixed at what value? For how long?
%-------------------------------------------------

dkeeper = 1 : 5;

p_stay  = 1;
p_exit  = 1-p_stay;
K                         = length(dkeeper);
multiplier_deterministic  = zeros(1,K);
ykeeper                   = zeros(K,1);
     
sigma  = 2;
beta   = 0.99;
theta  = 0.85;
kappa  = 0.03; % (1-beta*theta)*(1-theta)/(theta);
gamma  = 0.29;
N      = 1/3;

lambda= 0;
rho   = 0;
tau   = 1.5;
tau_y = 0.5;
g     = 0.2;
chi   = 1/2;

% order of variables in vector y_t
y       = 1;  
pie     = 2; 
R       = 3;
mac     = 4;
c       = 5;
gov     = 6;

% Model is of the form:
% A0*Y_{t} = A1*Y_{t-1} + A2*Y_{t+1}
 
dy = 6; dx = 1; dv = 1;

A0 = zeros(dy,dy);
A1 = zeros(dy,dy);
A2 = zeros(dy,dy);

%1. (1+beta*lambda)*pi = kappa*mac + beta*pi(+1); // NKPC
A0(1,pie)   = (1+beta*lambda);
A0(1,mac)   = -kappa;
A2(1,pie)   =  beta;
A1(1,pie)   = lambda;

% 2. r - pie(+1) = (gamma*(1-sigma)-1)*(c-c(+1)) - (1-gamma)*(1-sigma)N/(1-N)*(n-n(+1))
A0(2,R)   = 1;
A2(2,pie) = 1;
A0(2,c)   = -(gamma*(1-sigma)-1);
A2(2,c)   = -(gamma*(1-sigma)-1);
A0(2,y)   = (1-gamma)*(1-sigma)*N/(1-N);
A2(2,y)   = (1-gamma)*(1-sigma)*N/(1-N);

% 3. R = rho*R(-1) + (1-rho)*(tau*pie + tau_gap*y); // Taylor rule
A0(3,R)   = 1;
A1(3,R)   = rho;
A0(3,pie) = -(1-rho)*tau;
A0(3,y)   = -(1-rho)*tau_y;

% 4. mac - c = N/(1-N)*n
A0(4,mac) =  1;
A0(4,c)   = -1;
A0(4,y)   = -N/(1-N);

% 5. y = (1-g)*c + g*gov ; 
A0(5,y)     = 1;
A0(5,c)     = -(1-g);
A0(5,gov)   = -g;

% 6. gov = constant
A0(6,gov)   = 1;

% 3. solve model with stacked time approach
% -----------------------------------------
loc(1) = 3;  % which row in variable vector corresponds to interest rate?
loc(2) = 3;  % which equation is the interest rate in 
loc(3) = 6;  % which equaton is government spending in

multiplier_stochastic = [];

for j = 1 : K ;
    
    d          = dkeeper(j);
    s          = 1; %ones(1,d);
    q          = [repmat(1-p_exit,d-1,1);1-p_exit];
    [Z,P,J]    = solve_stacked(A0,A1,A2,d,loc,s,q); 
    IRF        = reshape(Z,dy,d);
    IRF_all    = IRF;
    ykeeper(j) = IRF_all(1,1);

    multiplier_deterministic(j) = ykeeper(j)/g;
    pe       = (d-1)/d;
    
    % There is a typo in the formula for the multiplier reported in CEE 
    % ystoch   = ( (1-beta*pe)*(1-pe)*(  gamma*(sigma-1)+1 )- pe*kappa)/( (1-beta*pe)*(1-pe) - kappa*pe*( 1 + N/(1-N)*(1-g) ) )
    
    mp = ((g*(gamma*(sigma - 1) + 1))/(g - 1) - (g*pe*(gamma*(sigma - 1) + 1))/(g - 1) + (g*kappa*pe)/((beta*pe - 1)*(g - 1)))/(g*((gamma*(sigma - 1) + 1)/(g - 1) - (pe*(gamma*(sigma - 1) + 1))/(g - 1) + (N*(gamma - 1)*(sigma - 1))/(N - 1) + (kappa*pe*(1/(g - 1) + N/(N - 1)))/(beta*pe - 1) - (N*pe*(gamma - 1)*(sigma - 1))/(N - 1)));
 
    multiplier_stochastic       = [multiplier_stochastic, mp];
end;

 

FS = 12;

figure(1)
subplot(2,1,1)
plot(dkeeper,multiplier_deterministic,'-r');  hold on;
plot(dkeeper,multiplier_stochastic,'--b'); hold on; axis square;
h = xlabel('T');
set(h,'FontSize',FS);
h = ylabel('Fiscal multiplier');
set(h,'FontSize',FS);
l = legend('deterministic exit','stochastic exit','Orientation','horizontal','Location','SouthOutside');  
lp = get(l,'position');  set(l,'position',[lp(1) lp(2)/1.25 lp(3) lp(4)]);  % sets the legend farther down
set(l,'FontSize',12);
legend('boxoff');
print('-depsc','MSS_12_444_Figure_1b');
