clc; clear all; close all;



dkeeper = [1:50];

sigma = 2;
beta  = 0.99;
lambda= 0;
rho   = 0;
tau   = 1.5;
tau_y = 0.5;
g     = 0.2;
nu    = 0.5; 

theta       = [0.83;0.85;0.87];

kappakeeper = [0.038;0.028;0.018]; %  (1-beta.*theta).*(1-theta)./(theta);

% order of variables in vector y_t
y       = 1;  
pie     = 2; 
R       = 3;
mac     = 4;
c       = 5;
gov     = 6;

% Model is of the form:
% A0*Y_{t} = A1*Y_{t-1} + A2*Y_{t+1}
 
dy = 6; dx = 1; dv = 1;

p.sigma = sigma;
p.beta  = beta;
p.nu    = nu;
p.g     = g;

for k = 1:3;

kappa   = kappakeeper(k); 
p.kappa = kappa;

f = @(x)cutoff(x,p)

cut = fsolve(f,0.8)

p_stay  = 1;
p_exit  = 1-p_stay;
K                         = length(dkeeper);
multiplier_deterministic  = zeros(1,K);
ykeeper                   = zeros(K,1);

A0 = zeros(dy,dy);
A1 = zeros(dy,dy);
A2 = zeros(dy,dy);


%1. (1+beta*lambda)*pi = kappa*mac + beta*pi(+1); // NKPC
A0(1,pie)   = (1+beta*lambda);
A0(1,mac)   = -kappa;
A2(1,pie)   =  beta;
A1(1,pie)   = lambda;

% 2. y = y(+1) -sigma*R  + sigma*pi(+1) // Household Euler
A0(2,c)  =  1;
A0(2,R)  =  1/sigma;
A2(2,c)  =  1;
A2(2,pie)=  1/sigma;

% 3. R = rho*R(-1) + (1-rho)*(tau*pie + tau_gap*y); // Taylor rule
A0(3,R)   = 1;
A1(3,R)   = rho;
A0(3,pie) = -(1-rho)*tau;
A0(3,y)   = -(1-rho)*tau_y;

% 4. mac = sigma*c + nu*y ; // Taylor rule
A0(4,mac)   = 1;
A0(4,c)     = -sigma;
A0(4,y)     = -nu;

% 5. y = (1-g)*c + g*gov ; 
A0(5,y)     = 1;
A0(5,c)     = -(1-g);
A0(5,gov)   = -g;
    
% 6. gov = constant
A0(6,gov)   = 1;

% 3. solve model with stacked time approach
% -----------------------------------------
loc(1) = 3;  % which variable is interest rate
loc(2) = 3;  % which equation is interest rate in 
loc(3) = 6;  % which equaton is government spending in


for j = 1 : K ;
    
    d          = dkeeper(j);
    s          = ones(1,d);
    q          = repmat(1-p_exit,d,1);
    [Z,P,J]    = solve_stacked_fiscal(A0,A1,A2,d,loc,s,q); 
    IRF        = reshape(Z,dy,d);
    ydet(j,1)  = IRF(1,1)/g;
    
end;

loop(k).ydet = ydet;


pkeeper = 0.1 : 1/10000 : cut;


ystoch = zeros(length(pkeeper),1);
dstoch = zeros(length(pkeeper),1);


for j = 1 : length(pkeeper)
    pe         = pkeeper(j);
    ystoch(j)  = g*sigma*((1-pe)*(1-beta*pe)-kappa*pe )/(g*(sigma*(1-pe)*(1-beta*pe)-kappa*pe*(sigma+nu*(1-g))));
    dstoch(j)  = 1/(1-pe); 

end;

loop(k).ystoch = ystoch;
loop(k).dstoch = dstoch;


loop(k).ddet= interp1( ydet,[1:50],ystoch,'linear');

end;

figure(1)

plot(loop(1).dstoch,loop(1).ddet,'-r');   hold on;
plot(loop(2).dstoch,loop(2).ddet,'--r');  hold on;
plot(loop(3).dstoch,loop(3).ddet,'-.r');  hold on;
plot([0:1/100:8],[0:1/100:8],'-k');       hold on;
h=legend(['\kappa=',num2str(kappakeeper(1))],['\kappa=',num2str(kappakeeper(2))],['\kappa=',num2str(kappakeeper(3))],'45 degree line','Location','Northwest');
set(h,'Box','off');
set(h,'FontSize',14);
xlim([0,8]);
ylim([0,50]);
h=xlabel('mean duration of stochastic exit');
set(h,'FontSize',14);
h=ylabel('duration for deterministic exit');
set(h,'FontSize',14);
print('-depsc','MSS_12_444_Figure_2');



