clc; clear all; close all;

diary('diary.txt');

fprintf('\n Figure 5: Note this takes several hours ... \n');

% order of variables in vector y_t
mac  = 1;
kap  = 2; 
ivn  = 3; 
pin  = 4;    
con  = 5;
prk  = 6; 
out  = 7; 
lab  = 8; 
wag  = 9;
noi  = 10;
gov  = 11;

d       = 4;
s       = 1;
q       = ones(d,1);

p_stay = 3/4;
p_exit = 1-p_stay;

loc(1,1) = 10;  % which row is Taylor rule
loc(2,1) = noi; % which row in variable vector is interest rate
loc(3,1) = 11;  % which equaton is government spending in

% Now solve system conditional on exit

keeper =[];

counter = 0;
candidate = 0;
pass_A  = 0;
pass_B  = 0;

while counter  < 10000;
    
candidate = candidate + 1;

[A0,A1,A2] = get_model_capital_random;
n          = length(A0);

g0  = [[A0,-A2];[eye(n), zeros(n)]];           % coefficients on current period variables (including expectations of tomorrows variables as separate variables)
g1	= [[A1,zeros(n)];[zeros(n),eye(n)]];       % coefficients on last period variables
c   = zeros(2*n,1);                            % constant (not present in terminal regime)
psi = [zeros(n,1);zeros(n,1)];                 % coefficients on structural shocks 
pie = [zeros(n);eye(n)];                       % coefficients on expectational errors
div = 1;                                       % cutoff between explosive and non-explosive roots

addpath([cd,'\gensys']);
    [NA,c,NB,fmat,fwt,ywt,gev,eu] = gensys(g0,g1,c,psi,pie,div);
rmpath([cd,'\gensys']);

if min(eu==[1;1])==0;
   continue; fprintf('\n Indeterminacy in terminal regime \n'); 
end

pass_A = pass_A +1;

% Extract transition matrix (discard expectational variables that are of no interest here)
P = NA(1:n,1:n);

% now solve the system with stochastic exit

AA0 = A0; 
AA1 = A1;
AA2 = A2;

AA0(loc(1),:)      = zeros(1,n);
AA0(loc(1),loc(2)) = 1;
AA1(loc(1),:)      = zeros(1,n);
AA2(loc(1),:)      = zeros(1,n);

g0  = [[AA0-p_exit*AA2*P,-(1-p_exit)*AA2];[eye(n), zeros(n)]];           % coefficients on current period variables (including expectations of tomorrows variables as separate variables)
g1	= [[AA1,zeros(n)];[zeros(n),eye(n)]];       % coefficients on last period variables
c   = [[zeros(n-1,1);s];zeros(n,1)];           % constant (not present in terminal regime)
psi = zeros(2*n,1);                            % coefficients on structural shocks

pie = [zeros(n);eye(n)];                       % coefficients on expectational errors
div = 1;                                       % cutoff between explosive and non-explosive roots

addpath([cd,'\gensys']);
  [NA,c,NB,fmat,fwt,ywt,gev,eu] = gensys(g0,g1,c,psi,pie,div);
rmpath([cd,'\gensys']);

if min(eu==[1;1])==0;
    continue; fprintf('\n Indeterminacy in stochastic exit model \n'); 
end

pass_B = pass_B + 1;

% Extract transition matrix (discard expectational variables that are of no interest here)
AA = NA(1:n,1:n);
BB = NB(1:n,1);

multiplier_stochastic = 5*c(out);

[Z,P,J] = solve_stacked_fiscal(A0,A1,A2,d,loc,ones(d,1),q); 
IRF     = reshape(Z,n,d);
multiplier_deterministic = 5*IRF(out,1);

ratio = multiplier_stochastic/multiplier_deterministic;
counter = counter +1;

if ratio < 1;
    multiplier_stochastic
    multiplier_deterministic
end

keeper = [keeper;ratio];
    
    
end;

step    = (max(keeper) - min(keeper))/100;
buckets = min(keeper) : step : max(keeper);

[n,xout] = hist(keeper,buckets);
figure(1)
bar(xout,n./length(keeper)); axis tight;

% mean(keeper)
% median(keeper)
% stdv(keeper)
% min(keeper)
% max(keeper)

K = sort(keeper);

M      = K;
M(find(M>40))= [];

median(M)
sqrt(cov(M))

small = 1/100;

figure(2)
addpath([cd,'\kernel']);
   ksdensity(M,'kernel','epanechnikov','support',[min(M)-small,max(M)+small]); axis tight;
rmpath([cd,'\kernel']);
h = xlabel('ratio of fiscal multipliers'); set(h,'FontSize',14);
h = ylabel('density');  set(h,'FontSize',14);
print('-depsc','MSS_12_444_Figure_5');


diary off;
    
