clc;  clear all;  close all;

fprintf('\n  Computing solutions to nonlinear Rotemberg model \n');
fprintf('\n  Uses symbolic math and is really slow  \n');


setup = 'with shock';

switch setup
    case 'with shock'
          DL   = (1 + 2/100);
          Tval = [3,4,5,6];
    case 'without shock'
          DL   = (1 + 0/100);
          Tval = [3,4,5,5.85472];
end


for T = Tval;

p       = (T-1)/T;
sigma   = 2;
beta    = 0.99;
phi     = 1/2;
theta   = 0.85;
kappa   = (1-beta*theta)*(1-theta)/(theta);
epsilon = 11;
acp     = (epsilon-1)/kappa;
s       = 0.2;

tau         = epsilon/(epsilon-1);
s           = 0.2;
C_terminal  = (1-s)^(phi/(phi+sigma));
Y_terminal  = C_terminal^(-sigma/phi);
Pi_terminal = 1;

if DL == 1;
    R_terminal  = 1/beta;
    R_constant  = 1/beta;
else
    R_terminal  = 1;
    R_constant  = 1;
end


for dg = [ 0 , 10^(-2)];

syms Y Pi real

G = s*Y_terminal*(1+dg);
C = Y*(1-acp/2*(Pi-1)^2) - G;


FOC_1 = -(epsilon-1)*C^(-sigma)*Y + (epsilon-1)*Y^phi*C^sigma*C^(-sigma)*Y - acp*(Pi-1)*Pi*C^(-sigma)*Y + ...
                        p*C^(-sigma)*DL*beta*acp*(Pi-1)*Pi*Y + ...
                   (1-p)*C_terminal^(-sigma)*DL*beta*acp*(Pi_terminal-1)*Pi_terminal*Y_terminal;
               
FOC_2 = C^(-sigma) - p*beta*DL*R_constant*C^(-sigma)/Pi - (1-p)*DL*beta*R_constant*C_terminal^(-sigma)/Pi_terminal;


out = solve(FOC_1,FOC_2,Y,Pi);

% eliminate spurious solutions
check_1 = subs(FOC_1, {Y,Pi}, {out.Y,out.Pi});
check_2 = subs(FOC_2, {Y,Pi}, {out.Y,out.Pi});
index   = find( (abs(double(check_1)) <10^(-6)) & (abs(double(check_2)) <10^(-6)) ); 

if dg == 0
  Y0 = double(out.Y(index));
  P0 = double(out.Pi(index));
elseif dg == 10^(-2)
  Y1 = double(out.Y(index));
  P1 = double(out.Pi(index));
end

end;

% eliminate complex solutions, negative price levels or negative output
index1 = [];
index0 = [];

for k = 1: length(Y1);
    check1 = isreal(P1(k)) & (P1(k)>0) & isreal(Y1(k)) & (Y1(k)> 0);
    if check1 == 1;
        index1 = [index1,k];
    end
    check0 = isreal(P0(k)) & (P0(k)>0) & isreal(Y0(k)) & (Y1(k)> 0);
    if check0 == 1;
        index0 = [index0,k];
    end
end;

% work out consumption
S1 = [P1(index1),Y1(index1),0*Y0(index0)];
for j= 1:length(index1);
  S1(j,3) = S1(j,2)*(1-acp/2*(S1(j,1)-1)^2) - G ;
end;

% work out consumption
S0 = [P0(index0),Y0(index0),0*Y0(index0)];
for j= 1:length(index0);
  S0(j,3) = S0(j,2)*(1-acp/2*(S0(j,1)-1)^2) - s*Y_terminal;
end;

% make sure all values  are positive
SS1 = S1(all(S1(:,:)>0,2)==1,:);
SS0 = S0(all(S0(:,:)>0,2)==1,:);
 

% sort valid solutions according to inflation ...
SS1 = sort(SS1,1);
SS0 = sort(SS0,1);

 for j = 1:size(SS1,1)
    multiplier = (SS1(j,3) + dg*s*Y_terminal - SS0(j,3))/(dg*s*Y_terminal);
    fprintf('\n For T = %g, initial output multiplier is %g or ... \n ', T, multiplier  );
 end;


end;

