clc; 
clear all; 
close all;

global dg DL sigma beta acp phi epsi ;

sigma   = 2;
beta    = 0.99;
phi     = 1/2;
theta   = 0.85;
kappa   = (1-beta*theta)*(1-theta)/(theta);
epsilon = 11;
epsi    = epsilon;
acp     = (epsilon-1)/(kappa);
s       = 0.2;
DL      = (1 + 2/100);
delta   = 10^(-2);

C_terminal = (1-s)^(phi/(phi+sigma));
Y_terminal = C_terminal^(-sigma/phi);
P_terminal = 1;

T      = 6;
X      = zeros(T,2);
X(:,1) = repmat(P_terminal,T,1);
X(:,2) = repmat(Y_terminal,T,1);
X_SS   = X;

Parameters = [sigma; beta; acp; phi; epsilon];
options    = optimset('Display','Off','MaxFunEvals',10^8,'TolFun',10^(-16),'TolX',10^(-16),'MaxIter',10^8);
dg_keeper  = [0;delta];


for j = 0 : 1;
    
    dg     = dg_keeper(j+1);
    
    Solve      = @(Peter)Residual_Rotemberg(Peter);
    [IRF,fval,exitflag,output,jacobian] = fsolve(Solve,X,options);
    if exitflag == 1;
        fprintf('\n fsolve converged on solution \n');
    elseif exitflag == 0;
        fprintf('\n Maximum number of function evaluations or iterations was reached \n');
    end;
    fprintf('\n Maximum absolut deviation from equilibrium condition is %g, \n ', max(max(abs(Residual_Rotemberg(IRF))))  );
    if j == 0
        SOL_0 = IRF;
    else
        SOL_1 = IRF;
    end;
end;


G  = s*Y_terminal*(1+dg);
C0 = SOL_0(:,2).*(1-acp/2*(SOL_0(:,1)-1).^2) -s*Y_terminal ;
C1 = SOL_1(:,2).*(1-acp/2*(SOL_1(:,1)-1).^2) -G ;

multiplier = (C1 + dg*s*Y_terminal - C0)./(dg*s*Y_terminal);

fprintf('\n Initial output multiplier is %2.10f, \n ',  multiplier  );


