clc; 
clear all; 
close all;

global dg DL;

sigma   = 2;
beta    = 0.99;
phi     = 1/2;
slope   = 0.025/(sigma+phi);
theta   = (slope - (beta^2 + 2*beta*slope - 2*beta + slope^2 + 2*slope + 1)^(1/2) + 1)/(2*beta) + 1/2;
epsilon = 11;
acp     = epsilon/((1-theta)*(1-theta*beta)/theta);
s       = 0.2;
DL      = (1 + 2/100);
delta   = 10^(-2);

C_terminal = (1-s)^(phi/(phi+sigma));
Y_terminal = C_terminal^(-sigma/phi);
P_terminal = 1;

T      = 6;
X      = zeros(T,2);
X(:,1) = repmat(P_terminal,T,1);
X(:,2) = repmat(Y_terminal,T,1);
X_SS   = X;

scale1 = 1;
scale2 = 1;

Parameters = [sigma; beta; acp; phi; epsilon];
options    = optimset('Display','Off','MaxFunEvals',10^8,'TolFun',10^(-16),'TolX',10^(-16),'MaxIter',10^8);
dg_keeper  = [0;delta];

for dg = [ 0 , 10^(-2)];

syms Y Pi real

tau         = epsilon/(epsilon-1);
s           = 0.2;
C_terminal  = (1-s)^(phi/(phi+sigma));
Y_terminal  = C_terminal^(-sigma/phi);
Pi_terminal = 1;
R_terminal  = 1/beta;
R_constant  = 1;

G = s*Y_terminal*(1+dg);
C = Y*(1-acp/2*(Pi-1)^2) - G;

syms C Y Pi 
% Put in terminal conditions first
C      = Y*(1-acp*(Pi-1)^2) - G; 
FOC_1  = -(epsilon-1)*tau + epsilon*Y^phi*C^(sigma) - acp*(Pi-1)*Pi + DL*C_terminal^(-sigma)/C^(sigma)*beta*acp*(Pi_terminal-1)*Pi_terminal*Y_terminal/Y;
FOC_2  = C^(-sigma) - beta*DL*R_constant*C_terminal^(-sigma)*(1/Pi_terminal);



out = solve(FOC_1,FOC_2,Y,Pi);

% eliminate spurious solutions
check_1 = subs(FOC_1, {Y,Pi}, {out.Y,out.Pi});
check_2 = subs(FOC_2, {Y,Pi}, {out.Y,out.Pi});
index   = find( (abs(double(check_1)) <10^(-6)) & (abs(double(check_2)) <10^(-6)) ); 

if dg == 0
  Y0 = double(out.Y(index));
  P0 = double(out.Pi(index));
  save Y0 Y0
  save P0 P0
elseif dg == 10^(-2)
  Y1 = double(out.Y(index));
  P1 = double(out.Pi(index));
  save Y1 Y1
  save P1 P1
end

end;

% eliminate complex solutions ( based on P1 ... )
check = 1;
k     = 0;
while check == 1;
    check = isreal(P1(k+1));
    if check == 1;
        k = k+1;
    end
end;

S1 = sort([P1(1:k),Y1(1:k)]);
S0 = sort([P0(1:k),Y0(1:k)]);

for j= 1:k;
  C0 = S0(j,2)*(1-acp/2*(S0(j,1)-1)^2); % -s*Y_terminal ;
  C1 = S1(j,2)*(1-acp/2*(S1(j,1)-1)^2); % -G ;
  multiplier = (C1-C0)/(dg*s*Y_terminal);
  fprintf('\n Initial consumption multiplier is %g or ... \n ',  multiplier  );
end;

solution_T = input('Pick a solution corresponding to these multipliers: enter 1,2,3 etc...');

fprintf('\n Backing up to period T-1 \n');

return;

for dg = [ 0 , 10^(-2)];

syms Y Pi real

tau         = epsilon/(epsilon-1);
s           = 0.2;
C_terminal  = (1-s)^(phi/(phi+sigma));
Y_terminal  = C_terminal^(-sigma/phi);
Pi_terminal = 1;
R_terminal  = 1/beta;
R_constant  = 1;

G = s*Y_terminal*(1+dg);
C = Y*(1-acp/2*(Pi-1)^2) - G;

syms C Y Pi 
% Put in terminal conditions first
C      = Y*(1-acp*(Pi-1)^2) - G; 
FOC_1  = -(epsilon-1)*tau + epsilon*Y^phi*C^(sigma) - acp*(Pi-1)*Pi + DL*C_terminal^(-sigma)/C^(sigma)*beta*acp*(Pi_terminal-1)*Pi_terminal*Y_terminal/Y;
FOC_2  = C^(-sigma) - beta*DL*R_constant*C_terminal^(-sigma)*(1/Pi_terminal);



out = solve(FOC_1,FOC_2,Y,Pi);

% eliminate spurious solutions
check_1 = subs(FOC_1, {Y,Pi}, {out.Y,out.Pi});
check_2 = subs(FOC_2, {Y,Pi}, {out.Y,out.Pi});
index   = find( (abs(double(check_1)) <10^(-6)) & (abs(double(check_2)) <10^(-6)) ); 

if dg == 0
  Y0 = double(out.Y(index));
  P0 = double(out.Pi(index));
  save Y0 Y0
  save P0 P0
elseif dg == 10^(-2)
  Y1 = double(out.Y(index));
  P1 = double(out.Pi(index));
  save Y1 Y1
  save P1 P1
end

end;

% eliminate complex solutions ( based on P1 ... )
check = 1;
k     = 0;
while check == 1;
    check = isreal(P1(k+1));
    if check == 1;
        k = k+1;
    end
end;

S1 = sort([P1(1:k),Y1(1:k)]);
S0 = sort([P0(1:k),Y0(1:k)]);

for j= 1:k;
  C0 = S0(j,2)*(1-acp/2*(S0(j,1)-1)^2); % -s*Y_terminal ;
  C1 = S1(j,2)*(1-acp/2*(S1(j,1)-1)^2); % -G ;
  multiplier = (C1-C0)/(dg*s*Y_terminal);
  fprintf('\n Initial consumption multiplier is %g or ... \n ',  multiplier  );
end;





