function [AA0,AA1,AA2,AA3] = get_model_capital_MSRE

% fixed parameters
kappa  = 0.03;
alpha  = 0.345;
beta   = 0.99;
delta  = 0.02;
sigma  = 2;
gamma  = 0.29;
sigma_i= 17;
GY     = 0.2;
N      = 1/3;
tau(1) = 1.5;
tau(2) = 0;
dummy(1)= 0;
dummy(2)= 1;

% derived from steady state
KN = ((1/beta -1 + delta)/alpha)^(1/(alpha-1));
YK = KN^(alpha-1);
IY = delta/YK;
CK = YK*(1-GY) - delta;
CY = CK/YK;
epsilon = beta*(1-delta);

% order of variables in vector y_t
mac  = 1;
kap  = 2; 
pin  = 3;    
con  = 4;
lab  = 5; 

gov  = 1;

% Model is of the form:
% A0*Y_{t} = A1*Y_{t-1} + A2*Y_{t+1} + A3*Z_t
dy = 5; 
dz = 1;

AA0 = cell(2,1);
AA1 = cell(2,1);
AA2 = cell(2,1);
AA3 = cell(2,1);



for s = 1:2

A0 = zeros(dy,dy);
A1 = zeros(dy,dy);
A2 = zeros(dy,dy);
A3 = zeros(dy,dz);


% 1. pie = kappa*x + beta*pie(+1)
A0(1,pin) =  1;
A0(1,mac) = -kappa;
A2(1,pin) =  beta;

% 2. c +  N/(1-N)*n = mc + alpha*(k(-1) - n);
A0(2,con) = 1;
A0(2,lab) = N/(1-N)+alpha;
A0(2,mac) = -1;
A1(2,kap) = alpha;

% 3. r - pie(+1) = (gamma*(1-sigma)-1)*(c-c(+1)) - (1-gamma)*(1-sigma)N/(1-N)*(n-n(+1))
% with: r = tau*pin
A0(3,pin) = tau(s);
A2(3,pin) = 1;
A0(3,con) = -(gamma*(1-sigma)-1);
A2(3,con) = -(gamma*(1-sigma)-1);
A0(3,lab) = (1-gamma)*(1-sigma)*N/(1-N);
A2(3,lab) = (1-gamma)*(1-sigma)*N/(1-N);

% 4. r - pie(+1) =  (1-epsilon)*((1-alpha)*(n(+1) - k + x(+1)) +
% epsilon*sigma_i*(k(+1) - k) - sigma_i*(k -k(-1))
% with: r = tau*pin
A0(4,pin) = tau(s);
A2(4,pin) = 1;
A2(4,lab) =  (1-epsilon)*(1-alpha);
A0(4,kap) =  (1-epsilon)*(1-alpha) + epsilon*sigma_i + sigma_i;
A2(4,mac) =  1-epsilon;
A2(4,kap) =  epsilon*sigma_i;
A1(4,kap) =  sigma_i;

% 5 alpha*k(-1) + (1-alpha)*n = CY*c + IY/delta*(k-(1-delta)*k(-1)) + GY*g
A1(5,kap) = - alpha - IY/delta*(1-delta);
A0(5,lab) =  (1-alpha);
A0(5,kap) = -IY/delta;
A0(5,con) = -CY;
A3(5,gov) = GY*dummy(s);

AA0(s) = {A0};
AA1(s) = {A1};
AA2(s) = {A2};
AA3(s) = {A3};


end


