function [Residual] = Residual_Rotemberg(X)

global dg DL sigma beta acp phi epsi 

X = real(X);

T        = size(X,1);
Residual = ones(T,2);

Pi    = X(:,1);
Y     = X(:,2);

s           = 0.2;
C_terminal  = (1-s)^(phi/(phi+sigma));
Y_terminal  = C_terminal^(-sigma/phi);
Pi_terminal = 1;
R_constant  = 1;


G = s*Y_terminal*(1+dg);

% Main dynamic equations
for t = 1:T-1
    % 3. Market clearing
    C(t)          =   Y(t)*(1-acp/2*(Pi(t)  -1)^2) - G; 
    C(t+1)        = Y(t+1)*(1-acp/2*(Pi(t+1)-1)^2) - G; 
    % 1. FOC price setting
    Residual(t,1) = -(epsi-1) + (epsi-1)*Y(t)^phi*C(t)^(sigma) - acp*(Pi(t)-1)*Pi(t) + ...
                            DL*C(t+1)^(-sigma)/C(t)^(-sigma)*beta*acp*(Pi(t+1)-1)*Pi(t+1)*Y(t+1)/Y(t);
    % 2. Euler equation
    Residual(t,2) = 1 - beta*DL*R_constant*((C(t)/C(t+1))^sigma)*(1/Pi(t+1));   
    
end;

% Put in terminal conditions first
C(T)           = Y(T)*(1-acp/2*(Pi(T)-1)^2) - G; 
Residual(T,1)  = -(epsi-1) + (epsi-1)*Y(T)^phi*C(T)^(sigma) - acp*(Pi(T)-1)*Pi(T) + DL*C_terminal^(-sigma)/C(T)^(sigma)*beta*acp*(Pi_terminal-1)*Pi_terminal*Y_terminal/Y(T);
Residual(T,2)  = 1 - beta*DL*R_constant*((C(T)/C_terminal)^sigma)*(1/Pi_terminal);


% Residual = Residual*1000;

