clear all;
clc;

fprintf('\n Fiscal multiplier in the hybrid model - separable preferences \n');
fprintf('\n ------------------------------------------------------------- \n');

z  = [];
gridpoints =  [6,50,100,1000,10000];

% gridpoints =  [3,4,5,6];


sigma = 2;
beta  = 0.99;
theta = 0.85;
kappa = (1-beta*theta)*(1-theta)/(theta);
g     = 0.2;
nu    = 1/2;
p     = 5/6;
dg    = 0.01;

% 1. pi1  = kappa*mac + beta*p*pi2; 
% 2. c1   = p*c2 -1/sigma*constant  + 1/sigma*p*pi2
% 3. mac1  = sigma*c1 + nu*y1 ;
% 4. y1    = (1-g)*c1 + g*gov1 ; 

syms mac1 mac2 g1 g2 pi1 pi2 y1 y2 c1 c2 pi3

y1   = (1-g)*c1 + g*g1; 
mac1 = sigma*c1 + nu*y1;
f1   = -pi1 + kappa*mac1 + beta*p*pi2;
c1   = solve(f1,c1);
c2   = subs(c1,[pi2,pi1,g1],[pi3,pi2,g2]);

f2   = simplify(-c1 + p*c2  + 1/sigma*p*pi2);

pi1_c = simplify(diff(f2,pi1)); 
pi2_c = simplify(diff(f2,pi2));
pi3_c = simplify(diff(f2,pi3));
g1_c  = simplify(diff(f2,g1));
g2_c  = simplify(diff(f2,g2));

f2_check = pi1_c*pi1 + pi2_c*pi2 + pi3_c*pi3 + g1_c*g1 + g2_c*g2;

% finding terminal conditions

syms piT pistar piTT piT1 real

piT  = eval(solve(subs(f2_check,[pi3,pi2,pi1,g2,g1],[0,0,piT,0,dg]),piT));
piT1 = eval(solve(subs(f2_check,[g2,g1,pi3,pi2,pi1],[dg,dg,0,piT,piT1]),piT1));

% find the particular solution to non-homogenous equation
syms pistar
pistar = eval(solve(subs(f2_check,[pi1,pi2,pi3,g1,g2],[pistar,pistar,pistar,dg,dg]),pistar));

pistar_check = subs(f2_check,[pi1,pi2,pi3,g1,g2],[pistar,pistar,pistar,dg,dg]);

% find solution to homogenous equation
S = solve('pi3_c*x^2 + pi2_c*x + pi1_c');

N  = eval(S);
e1 = eval(N(1));
e2 = eval(N(2));

% impose terminal conditions

syms m1 m2 T real;

zT  = pistar + m1*e1^T     + m2*e2^T;
zT1 = pistar + m1*e1^(T-1) + m2*e2^(T-1);
r1  = -zT  + piT;
r2  = -zT1 + piT1;
S   = solve(r1,r2,m1,m2);
m1  = S.m1;
m2  = S.m2;

pi_initial = [];

for j = 1:length(gridpoints);

    mc  = ((pistar + m1*e1^1 + m2*e2^1) - beta*p*(pistar + m1*e1^2 + m2*e2^2))/kappa;
    T   = gridpoints(j);
    mcn = eval(simplify(mc));
    yinitial = ((1-g)/sigma*mcn + g*dg)/(1+(1-g)*nu/sigma);
    
    fprintf('\n Hybrid exit multiplier is %2.2f \n ',yinitial/(g*dg));
end;

      