function [A0,A1,A2] = get_model_capital(gamma)

% fixed parameters
kappa = 0.03;
alpha = 0.345;
beta  = 0.99;
delta = 0.02;
sigma = 2;
adj   = 17;
GY    = 0.2;
N     = 1/3;
tau   = 1.5;

% derived from steady state
KN = ((1/beta -1 + delta)/alpha)^(1/(alpha-1));
YK = KN^(alpha-1);
IY = delta/YK;
CK = YK*(1-GY) - delta;
CY = CK/YK;
epsilon = beta*(1-delta);

% order of variables in vector y_t
mac  = 1;
kap  = 2; 
ivn  = 3; 
pin  = 4;    
con  = 5;
prk  = 6; 
out  = 7; 
lab  = 8; 
wag  = 9;
noi  = 10;
dum  = 11;
gov  = 12;
% Model is of the form:
% A0*Y_{t} = A1*Y_{t-1} + A2*Y_{t+1}
dy = 12; 
A0 = zeros(dy,dy);
A1 = zeros(dy,dy);
A2 = zeros(dy,dy);

% 1. pie = kappa*x + beta*pie(+1)
A0(1,pin) =  1;
A0(1,mac) = -kappa;
A2(1,pin) =  beta;
% 2. w - c = N/(1-N)*n
A0(2,wag) =  1;
A0(2,con) = -1;
A0(2,lab) = -N/(1-N);
% 3. r - pie(+1) = (gamma*(1-sigma)-1)*(c-c(+1)) - (1-gamma)*(1-sigma)N/(1-N)*(n-n(+1))
A0(3,noi) = 1;
A2(3,pin) = 1;
A0(3,con) = -(gamma*(1-sigma)-1);
A2(3,con) = -(gamma*(1-sigma)-1);
A0(3,lab) = (1-gamma)*(1-sigma)*N/(1-N);
A2(3,lab) = (1-gamma)*(1-sigma)*N/(1-N);
% 4. r - pie(+1) =  (1-epsilon)*(y(+1) - k + x(+1)) + epsilon*q(+1) - q
A0(4,noi) = 1;
A2(4,pin) = 1;
A2(4,out) =  1-epsilon;
A0(4,kap) =  1-epsilon;
A2(4,mac) =  1-epsilon;
A2(4,prk) =  epsilon;
A0(4,prk) =  1;
% 5. q = adj*delta*( i - k(-1))
A0(5,prk) = 1;
A0(5,ivn) = -adj*delta;
A1(5,kap) = -adj*delta;
% 6. w = x + y - n;
A0(6,wag) =  1;
A0(6,mac) = -1;
A0(6,out) = -1;
A0(6,lab) =  1;
% 7. y = alpha*k(-1) + (1-alpha)*n
A0(7,out) = 1;
A1(7,kap) = alpha;
A0(7,lab) = -(1-alpha);
% 8. y = C/Y*c + I/Y*i + G/Y*g
A0(8,out) = 1;
A0(8,con) = -CY;
A0(8,ivn) = -IY;
A0(8,gov) = -GY;
% 9. k = (1-delta)*k(-1) + delta*i
A0(9,kap) = 1;
A1(9,kap) = 1-delta;
A0(9,ivn) = -delta;
% 10. i = tau*pie
A0(10,noi) = 1;
A0(10,pin) = -tau;

% 11. dummy
A0(11,dum) = -1;
A0(11,pin)  =  1;
A0(11,mac)  = -kappa;

% 12. gov equation for completeness
A0(12,gov) = 1;
A1(12,gov) = 1;      
