function [Z,P,J] = solve_stacked(A0,A1,A2,d,loc,s,q); 


% INPUT:   
%          A0,A1,A2               - system matrices
%          duration               - fixed for how long
%          loc                    - row of Taylor rule, column of R
%          s                      - interest rate fixed at what level?
%          q                      - 1-probability of reverting to Taylor rule
% 
% OUTPUT: Z                       - equilibrium in fixed rate regime
%         P                       - transition matrix in post-terminal regime
%         J                       - the matrix that is being inverted in stacked time approach
%
% Model is of the form:
% ---------------------------------
% A0*Y_{t} = A1*Y_{t-1} + A2*Y_{t+1}


n  = size(A1,1);   % number of variables


% Now put terminal system into gensys format to solve  
g0  = [[A0,-A2];[eye(n), zeros(n)]];           % coefficients on current period variables (including expectations of tomorrows variables as separate variables)
g1	= [[A1,zeros(n)];[zeros(n),eye(n)]];       % coefficients on last period variables
c   = zeros(2*n,1);                            % constant (not present in terminal regime)
psi = [zeros(n,1);zeros(n,1)];                 % coefficients on structural shocks 
pie = [zeros(n);eye(n)];                       % coefficients on expectational errors
div = 1;                                       % cutoff between explosive and non-explosive roots

addpath([cd,'\gensys']);
    [NA,c,NB,fmat,fwt,ywt,gev,eu] = gensys(g0,g1,c,psi,pie,div);
rmpath([cd,'\gensys']);

% Extract transition matrix (discard expectational variables that are of no interest here)
P = NA(1:n,1:n);

max_eig = max(abs(eig(P)));

% fprintf('\n Maximum eigenvalue of the system = %g \n',max_eig);


% Set up the system matrix J*Z = M
% ---------------------------------
% Replace Taylor rule with fixed rate 

A0(loc(1),:)      = zeros(1,n);
A0(loc(1),loc(2)) = 1;
A1(loc(1),:)      = zeros(1,n);
A2(loc(1),:)      = zeros(1,n);

J = sparse(n*d,n*d);

if d >= 3;
	% enter first period separate, because it's different
	J(1:n , 1:2*n ) = [A0-(1-q(1))*A2*P,-q(1)*A2];
	% enter all other periods but last
	for k = 2 : d-1;
	    J( (k-1)*n + 1 : k*n , (k-2)*n + 1 : (k-2)*n + 3*n)  = [-A1, A0-(1-q(k))*A2*P,-q(k)*A2];
	end;
	% enter last period separate, because it's different
	J( (d-1)*n+1 : d*n , (d-2)*n +1 : d*n ) = [-A1,A0-A2*P];
elseif d == 2;
    % enter first period separate, because it's different
	J(1:n , 1:2*n ) = [A0-(1-q(1))*A2*P,-q(1)*A2];
	% enter last period separate, because it's different
	J( n+1:2*n , 1:2*n ) = [-A1,A0-A2*P];
elseif d == 1;
    % enter first period separate, because it's different
	J(1:n , 1:n ) = [A0-A2*P];
end;	


% Now the constant vector

% M = [];
% for j = 1 :d;
%    con         = zeros(n,1);
%    con(loc(3)) = s(j);
%    M = [M;con];
% end;

 con         = zeros(n,1);
 con(loc(3)) = s;

M = repmat(con,d,1);

% solve the system
%-----------------
Z = J\M;
